==> gatsby-sports-theme-1.0.7.tgz: package/src/constants/standingTable.js <==
import {
  Column,
  goalScore,
  goalDifference,
  teamName,
  winsPercentage,
  pointsDifference,
} from '../helpers/standings';

///Soccer

export const soccerOverall = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.played', 'M', 'mobileActive'),
  new Column('data.wins', 'W'),
  new Column('data.draws', 'D'),
  new Column('data.defeits', 'L'),
  new Column('', 'GS', 'mobileActive', goalScore),
  new Column('', 'GD', null, goalDifference),
  new Column('data.points', 'P', 'mobileActive'),
];

export const soccerHome = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.winshome', 'W', 'mobileActive'),
  new Column('data.drawshome', 'D'),
  new Column('data.defeitshome', 'L'),
  new Column('', 'Win%', null, winsPercentage, 'homeWin'),
  new Column('data.goalsforhome', 'GFH', 'mobileActive'),
  new Column('data.goalsagainsthome', 'GAH'),
  new Column('data.pointshome', 'PH', 'mobileActive'),
];

export const soccerAway = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.winsaway', 'W', 'mobileActive'),
  new Column('data.drawsaway', 'D'),
  new Column('data.defeitsaway', 'L'),
  new Column('', 'Win%', null, winsPercentage, 'awayWin'),
  new Column('data.goalsforaway', 'GFA', 'mobileActive'),
  new Column('data.goalsagainstaway', 'GAA'),
  new Column('data.pointsaway', 'PA', 'mobileActive'),
];

export const soccerFirstHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.wins1h', 'W', 'mobileActive'),
  new Column('data.draws1h', 'D'),
  new Column('data.defeits1h', 'L'),
  new Column('', 'Win%', null, winsPercentage, '1stHalf'),
  new Column('data.goalsfor1h', 'GF1H', 'mobileActive'),
  new Column('data.goalsagainst1h', 'GA1H'),
  new Column('data.points1h', 'P1H', 'mobileActive'),
];

export const soccerSecondHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.wins2h', 'W', 'mobileActive'),
  new Column('data.draws2h', 'D'),
  new Column('data.defeits2h', 'L'),
  new Column('', 'Win%', null, winsPercentage, '2ndHalf'),
  new Column('data.goalsfor2h', 'GF2H', 'mobileActive'),
  new Column('data.goalsagainst2h', 'GA2H'),
  new Column('data.points2h', 'P2H', 'mobileActive'),
];

///American Futboll && Basketball

export const amOverall = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.played', 'M', 'mobileActive'),
  new Column('data.wins', 'wins', 'mobileActive'),
  new Column('data.defeits', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'overall'),
  new Column('data.pointsfor', 'pointsFor'),
  new Column('data.pointsagainst', 'pointsAgainst'),
  new Column('', 'pointsDifference', null, pointsDifference),
  new Column('data.winshome', 'homeWin'),
  new Column('data.winsaway', 'awayWin'),
];

export const amHome = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.winshome', 'wins', 'mobileActive'),
  new Column('data.defeitshome', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'homeWin'),
  new Column('data.pointsforhome', 'PFH', 'mobileActive'),
  new Column('data.pointsagainsthome', 'PAH'),
];

export const amAway = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.winsaway', 'wins', 'mobileActive'),
  new Column('data.defeitsaway', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'awayWin'),
  new Column('data.pointsforaway', 'PFA', 'mobileActive'),
  new Column('data.pointsagainstaway', 'PAA'),
];

export const amFirstHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.wins1h', 'wins', 'mobileActive'),
  new Column('data.defeits1h', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, '1stHalf'),
  new Column('data.pointsfor1h', 'PF1H', 'mobileActive'),
  new Column('data.pointsagainsthome1h', 'PA1H'),
];

export const amSecondHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.wins2h', 'wins', 'mobileActive'),
  new Column('data.defeits2h', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, '2ndHalf'),
  new Column('data.pointsfor2h', 'PF2H', 'mobileActive'),
  new Column('data.pointsagainsthome2h', 'PA2H'),
];

==> gatsby-sports-theme-1.0.37.tgz: package/src/constants/standingTable.js <==
/* eslint-disable import/no-cycle */
import {
  Column,
  // eslint-disable-next-line no-unused-vars
  goalScore,
  goalDifference,
  teamName,
  winsPercentage,
  pointsDifference,
} from '../helpers/standings';

/// Soccer

export const soccerOverall = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.played', 'M', 'mobileActive'),
  new Column('data.wins', 'W'),
  new Column('data.draws', 'D'),
  new Column('data.defeits', 'L'),
  // new Column('', 'GS', 'mobileActive', goalScore),
  new Column('', 'GD', null, goalDifference),
  new Column('data.points', 'P', 'mobileActive'),
];

export const soccerHome = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.winshome', 'W', 'mobileActive'),
  new Column('data.drawshome', 'D'),
  new Column('data.defeitshome', 'L'),
  new Column('', 'Win%', null, winsPercentage, 'homeWin'),
  new Column('data.goalsforhome', 'GFH', 'mobileActive'),
  new Column('data.goalsagainsthome', 'GAH'),
  new Column('data.pointshome', 'PH', 'mobileActive'),
];

export const soccerAway = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.winsaway', 'W', 'mobileActive'),
  new Column('data.drawsaway', 'D'),
  new Column('data.defeitsaway', 'L'),
  new Column('', 'Win%', null, winsPercentage, 'awayWin'),
  new Column('data.goalsforaway', 'GFA', 'mobileActive'),
  new Column('data.goalsagainstaway', 'GAA'),
  new Column('data.pointsaway', 'PA', 'mobileActive'),
];

export const soccerFirstHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.wins1h', 'W', 'mobileActive'),
  new Column('data.draws1h', 'D'),
  new Column('data.defeits1h', 'L'),
  new Column('', 'Win%', null, winsPercentage, '1stHalf'),
  new Column('data.goalsfor1h', 'GF1H', 'mobileActive'),
  new Column('data.goalsagainst1h', 'GA1H'),
  new Column('data.points1h', 'P1H', 'mobileActive'),
];

export const soccerSecondHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team', 'mobileActive', teamName),
  new Column('data.wins2h', 'W', 'mobileActive'),
  new Column('data.draws2h', 'D'),
  new Column('data.defeits2h', 'L'),
  new Column('', 'Win%', null, winsPercentage, '2ndHalf'),
  new Column('data.goalsfor2h', 'GF2H', 'mobileActive'),
  new Column('data.goalsagainst2h', 'GA2H'),
  new Column('data.points2h', 'P2H', 'mobileActive'),
];

/// American Futboll && Basketball

export const amOverall = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.played', 'M', 'mobileActive'),
  new Column('data.wins', 'wins', 'mobileActive'),
  new Column('data.defeits', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'overall'),
  new Column('data.pointsfor', 'pointsFor'),
  new Column('data.pointsagainst', 'pointsAgainst'),
  new Column('', 'pointsDifference', null, pointsDifference),
  new Column('data.winshome', 'homeWin'),
  new Column('data.winsaway', 'awayWin'),
];

export const amHome = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.winshome', 'wins', 'mobileActive'),
  new Column('data.defeitshome', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'homeWin'),
  new Column('data.pointsforhome', 'PFH', 'mobileActive'),
  new Column('data.pointsagainsthome', 'PAH'),
];

export const amAway = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.winsaway', 'wins', 'mobileActive'),
  new Column('data.defeitsaway', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, 'awayWin'),
  new Column('data.pointsforaway', 'PFA', 'mobileActive'),
  new Column('data.pointsagainstaway', 'PAA'),
];

export const amFirstHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.wins1h', 'wins', 'mobileActive'),
  new Column('data.defeits1h', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, '1stHalf'),
  new Column('data.pointsfor1h', 'PF1H', 'mobileActive'),
  new Column('data.pointsagainsthome1h', 'PA1H'),
];

export const amSecondHalf = [
  new Column('data.rank', '#', 'mobileActive'),
  new Column('', 'team_name', 'mobileActive', teamName),
  new Column('data.wins2h', 'wins', 'mobileActive'),
  new Column('data.defeits2h', 'loss'),
  new Column('', 'winsP', 'mobileActive', winsPercentage, '2ndHalf'),
  new Column('data.pointsfor2h', 'PF2H', 'mobileActive'),
  new Column('data.pointsagainsthome2h', 'PA2H'),
];
